@@ -20,9 +20,9 @@ crew_controller_system2 <- function(
   workers = 1L,
   host = NULL,
   port = NULL,
+  seconds_interval = 0.5,
+  seconds_timeout = 10,
   seconds_launch = 30,
-  seconds_interval = 0.01,
-  seconds_timeout = 5,
   seconds_idle = Inf,
   seconds_wall = Inf,
   seconds_exit = 0.1,
@@ -31,8 +31,7 @@ crew_controller_system2 <- function(
   reset_globals = TRUE,
   reset_packages = FALSE,
   reset_options = FALSE,
-  garbage_collection = FALSE,
-  auto_scale = "demand"
+  garbage_collection = FALSE
 ) {
   router <- crew::crew_router(
     name = name,
@@ -45,8 +44,6 @@ crew_controller_system2 <- function(
   launcher <- system2_launcher_class$new(
     name = name,
     seconds_launch = seconds_launch,
-    seconds_interval = seconds_interval,
-    seconds_timeout = seconds_timeout,
     seconds_idle = seconds_idle,
     seconds_wall = seconds_wall,
     seconds_exit = seconds_exit,
@@ -57,11 +54,7 @@ crew_controller_system2 <- function(
     reset_options = reset_options,
     garbage_collection = garbage_collection
   )
-  controller <- crew::crew_controller(
-    router = router,
-    launcher = launcher,
-    auto_scale = auto_scale
-  )
+  controller <- crew::crew_controller(router = router, launcher = launcher)
   controller$validate()
   controller
 }
@@ -106,12 +99,8 @@ while (!is.null(out <- controller$pop(scale = FALSE))) {
   }
 }
 # Check the results
-all(sort(unlist(results$result)) == seq_len(200L))
-#> [1] TRUE
-length(unique(results$instance))
-#> [1] 4
-# View worker and task summaries.
-View(controller$summary())
+testthat::expect_true(all(sort(unlist(results$result)) == seq_len(200L)))
+testthat::expect_equal(length(unique(results$instance)), 4L)
 # Terminate the controller.
 controller$terminate()
 # Now outside crew, verify that the mirai dispatcher
