@@ -10,6 +10,7 @@ crew_test("crew_controller_group() method and signature compatibility", {
 })
 
 crew_test("crew_controller_group()", {
+  skip_if_low_dep_versions()
   skip_on_cran()
   skip_on_os("windows")
   a <- crew_controller_local(
@@ -30,25 +31,22 @@ crew_test("crew_controller_group()", {
   })
   expect_silent(x$validate())
   for (index in seq_len(2)) {
-    expect_false(x$controllers[[index]]$router$listening())
+    expect_null(x$controllers[[index]]$router$started)
   }
   x$start()
   expect_true(x$empty())
+  expect_false(x$saturated())
   expect_true(x$empty(controllers = "a"))
   expect_true(x$empty(controllers = "b"))
   for (index in seq_len(2)) {
-    crew_retry(
-      ~x$controllers[[index]]$router$listening(),
-      seconds_interval = 0.001,
-      seconds_timeout = 5
-    )
+    expect_true(x$controllers[[index]]$router$started)
   }
   crew_retry(
     ~{
       x$wait(seconds_timeout = 30)
       TRUE
     },
-    seconds_interval = 0.001,
+    seconds_interval = 0.1,
     seconds_timeout = 5
   )
   s <- x$summary()
@@ -59,6 +57,7 @@ crew_test("crew_controller_group()", {
     sort(
       c(
         "controller",
+        "worker_index",
         "worker_socket",
         "worker_connected",
         "worker_launches",
@@ -124,7 +123,7 @@ crew_test("crew_controller_group()", {
       envir$out <- x$pop(scale = TRUE)
       !is.null(envir$out)
     },
-    seconds_interval = 0.01,
+    seconds_interval = 0.1,
     seconds_timeout = 10
   )
   out <- envir$out
@@ -144,23 +143,22 @@ crew_test("crew_controller_group()", {
   handle <- x$controllers[[2]]$launcher$workers$handle[[1]]
   x$terminate()
   for (index in seq_len(2)) {
-    crew_retry(
-      ~!x$controllers[[index]]$router$listening(),
-      seconds_interval = 0.001,
-      seconds_timeout = 5
-    )
+    expect_false(x$controllers[[index]]$router$started)
     crew_retry(
       ~!handle$is_alive(),
-      seconds_interval = 0.001,
+      seconds_interval = 0.1,
       seconds_timeout = 5
     )
   }
 })
 
 crew_test("crew_controller_group() select", {
+  skip_if_low_dep_versions()
   skip_on_cran()
   skip_on_os("windows")
-  a <- crew_controller_local(name = "a")
+  a <- crew_controller_local(
+    name = "a"
+  )
   b <- crew_controller_local(
     name = "b",
     tasks_max = 1L,
@@ -173,18 +171,19 @@ crew_test("crew_controller_group() select", {
     gc()
     crew_test_sleep()
   })
-  expect_false(a$router$listening())
-  expect_false(b$router$listening())
+  expect_null(a$router$started)
+  expect_null(b$router$started)
   name <- "b"
   x$start(controllers = name)
-  expect_false(a$router$listening())
-  expect_true(b$router$listening())
+  expect_null(a$router$started)
+  expect_true(b$router$started)
   x$terminate(controllers = name)
-  expect_false(a$router$listening())
-  expect_false(b$router$listening())
+  expect_null(a$router$started)
+  expect_false(b$router$started)
 })
 
 crew_test("crew_controller_group() collect", {
+  skip_if_low_dep_versions()
   skip_on_cran()
   skip_on_os("windows")
   a <- crew_controller_local(
@@ -203,18 +202,19 @@ crew_test("crew_controller_group() collect", {
     crew_test_sleep()
   })
   expect_silent(x$validate())
-  expect_false(x$controllers[[1]]$router$listening())
-  expect_false(x$controllers[[2]]$router$listening())
+  expect_null(x$controllers[[1]]$router$started)
+  expect_null(x$controllers[[2]]$router$started)
   x$start()
   expect_null(x$pop())
   x$push(command = ps::ps_pid(), name = "task_pid")
   crew_retry(
     fun = ~{
+      x$scale()
       x$collect()
       length(x$controllers[[1]]$results) > 0L
     },
-    seconds_interval = 0.01,
-    seconds_timeout = 5
+    seconds_interval = 0.5,
+    seconds_timeout = 10
   )
   out <- x$pop(scale = FALSE, controllers = "a")
   expect_equal(
@@ -225,6 +225,7 @@ crew_test("crew_controller_group() collect", {
 })
 
 crew_test("crew_controller_group() launch method", {
+  skip_if_low_dep_versions()
   skip_on_cran()
   skip_on_os("windows")
   a <- crew_controller_local(
@@ -256,7 +257,7 @@ crew_test("crew_controller_group() launch method", {
   for (index in seq_len(2)) {
     crew_retry(
       ~handles[[index]]$is_alive(),
-      seconds_interval = 0.001,
+      seconds_interval = 0.1,
       seconds_timeout = 5
     )
   }
@@ -264,18 +265,18 @@ crew_test("crew_controller_group() launch method", {
   for (index in seq_len(2)) {
     crew_retry(
       ~!handles[[index]]$is_alive(),
-      seconds_interval = 0.001,
+      seconds_interval = 0.1,
       seconds_timeout = 5
     )
   }
 })
 
 crew_test("crew_controller_group() scale method", {
+  skip_if_low_dep_versions()
   skip_on_cran()
   skip_on_os("windows")
   a <- crew_controller_local(
     name = "a",
-    auto_scale = "one",
     seconds_idle = 360
   )
   x <- crew_controller_group(a)
@@ -290,19 +291,19 @@ crew_test("crew_controller_group() scale method", {
   expect_silent(x$scale())
   crew_retry(
     ~length(a$launcher$workers$handle) > 0L,
-    seconds_interval = 0.01,
+    seconds_interval = 0.1,
     seconds_timeout = 5
   )
   handle <- a$launcher$workers$handle[[1L]]
   crew_retry(
     fun = ~handle$is_alive(),
-    seconds_interval = 0.001,
+    seconds_interval = 0.1,
     seconds_timeout = 5
   )
   x$terminate()
   crew_retry(
     fun = ~!handle$is_alive(),
-    seconds_interval = 0.001,
+    seconds_interval = 0.1,
     seconds_timeout = 5
   )
 })
